@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright © 2020 NXP
-# Copyright © 2020 Chris Reed
+# Copyright © 2020-2021 Chris Reed
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -30,14 +30,13 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-import six
 from pypemicro import PyPemicro, PEMicroException, PEMicroTransferException, PEMicroInterfaces
 import logging
 from time import sleep
 
 from pyocd.probe.debug_probe import DebugProbe
 from pyocd.core.plugin import Plugin
-from pyocd.core import (exceptions, memory_interface)
+from pyocd.core import exceptions
 
 from ._version import version as plugin_version
 
@@ -46,6 +45,7 @@ LOG = logging.getLogger(__name__)
 TRACE = LOG.getChild("trace")
 TRACE.disabled = True
 
+
 class PEMicroProbe(DebugProbe):
     """! @brief Wraps a PEMicro as a DebugProbe."""
 
@@ -53,10 +53,9 @@ class PEMicroProbe(DebugProbe):
     DP_SELECT = 0x8
 
     # Bitmasks for AP register address fields.
-    APBANKSEL = 0x000000f0
+    APREG_MASK = 0x000000fc # APBANKSEL | A[3:2]
     APSEL = 0xff000000
     APSEL_SHIFT = 24
-    APSEL_APBANKSEL = APSEL | APBANKSEL
 
     ## Part of the error message for exceptions raised when there isn't a PEMicro library
     # matching the system's architecture, or other similar reasons.
@@ -86,9 +85,9 @@ class PEMicroProbe(DebugProbe):
         except PEMicroException as exc:
             # Ignore errors about a missing library, which can happen on systems not supported by
             # the PEMicro library but on which the plugin is installed.
-            if cls.NO_LIBRARY_ERR in exc.message:
+            if cls.NO_LIBRARY_ERR in str(exc):
                 return []
-            six.raise_from(cls._convert_exception(exc), exc)
+            raise cls._convert_exception(exc) from exc
 
     @classmethod
     def get_probe_with_id(cls, unique_id, is_explicit=False):
@@ -104,15 +103,15 @@ class PEMicroProbe(DebugProbe):
         except PEMicroException as exc:
             # Ignore errors about a missing library, which can happen on systems not supported by
             # the PEMicro library but on which the plugin is installed.
-            if cls.NO_LIBRARY_ERR not in exc.message:
+            if cls.NO_LIBRARY_ERR in str(exc):
                 return None
-            six.raise_from(cls._convert_exception(exc), exc)
+            raise cls._convert_exception(exc) from exc
 
     def __init__(self, serial_number):
         super(PEMicroProbe, self).__init__()
         self._pemicro = self._get_pemicro()
         if self._pemicro is None:
-            raise PEMicroException("unable to get PEMicro DLL")
+            raise exceptions.ProbeError("unable to get PEMicro DLL")
 
         self._serial_number = serial_number
         self._supported_protocols = None
@@ -126,7 +125,7 @@ class PEMicroProbe(DebugProbe):
             self._product_name = self._pemicro.version() or "Unknown"
             self._pemicro.close()
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     @property
     def description(self):
@@ -161,7 +160,12 @@ class PEMicroProbe(DebugProbe):
 
     @property
     def capabilities(self):
-        return {self.Capability.SWO, self.Capability.MANAGED_AP_SELECTION, self.Capability.BANKED_DP_REGISTERS, self.Capability.MANAGED_DPBANKSEL}
+        return {
+            self.Capability.SWO,
+            self.Capability.MANAGED_AP_SELECTION,
+            self.Capability.BANKED_DP_REGISTERS,
+            self.Capability.MANAGED_DPBANKSEL,
+            }
 
     def open(self):
         try:
@@ -178,14 +182,14 @@ class PEMicroProbe(DebugProbe):
             self._default_protocol = DebugProbe.Protocol.SWD
 
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def close(self):
         try:
             self._pemicro.close()
             self._is_open = False
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     # ------------------------------------------- #
     #          Target control functions
@@ -219,7 +223,7 @@ class PEMicroProbe(DebugProbe):
             self._pemicro.connect(iface, self.session.options.get("swv_clock"))
             self._protocol = protocol
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def swj_sequence(self, length, bits):
         raise NotImplementedError()
@@ -232,7 +236,7 @@ class PEMicroProbe(DebugProbe):
         try:
             self._pemicro.set_debug_frequency(frequency)
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def reset(self):
         try:
@@ -259,14 +263,14 @@ class PEMicroProbe(DebugProbe):
             sleep(self.session.options.get('reset.post_delay'))
 
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def assert_reset(self, asserted=False):
         try:
             self._pemicro.control_reset_line(asserted)
             self.reset_pin_state = not asserted
         except PEMicroException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def is_reset_asserted(self):
         return not self.reset_pin_state
@@ -278,13 +282,13 @@ class PEMicroProbe(DebugProbe):
         try:
             self._pemicro.flush_any_queued_data()
         except Exception as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def read_dp(self, addr, now=True):
         try:
             value = self._pemicro.read_dp_register(addr=addr, now=now)
         except PEMicroTransferException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
         else:
             def read_reg_cb():
                 return value
@@ -295,14 +299,16 @@ class PEMicroProbe(DebugProbe):
         try:
             self._pemicro.write_dp_register(addr=addr, value=data)
         except PEMicroTransferException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def read_ap(self, addr, now=True):
-        assert type(addr) in (six.integer_types)
+        assert isinstance(addr, int)
         try:
-            value = self._pemicro.read_ap_register(addr=(addr & self.APADDR), now=now, apselect= ((addr & self.APSEL_APBANKSEL) >> self.APSEL_SHIFT))
+            reg_addr = addr & self.APREG_MASK
+            ap_select = (addr & self.APSEL) >> self.APSEL_SHIFT
+            value = self._pemicro.read_ap_register(addr=reg_addr, now=now, apselect=ap_select)
         except PEMicroTransferException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
         else:
             def read_reg_cb():
                 return value
@@ -310,11 +316,13 @@ class PEMicroProbe(DebugProbe):
             return value if now else read_reg_cb
 
     def write_ap(self, addr, data, now = True):
-        assert type(addr) in (six.integer_types)
+        assert isinstance(addr, int)
         try:
-            self._pemicro.write_ap_register(addr=(addr & self.APADDR), value=data, apselect=((addr & self.APSEL_APBANKSEL) >> self.APSEL_SHIFT))
+            reg_addr = addr & self.APREG_MASK
+            ap_select = (addr & self.APSEL) >> self.APSEL_SHIFT
+            self._pemicro.write_ap_register(addr=reg_addr, value=data, apselect=ap_select)
         except PEMicroTransferException as exc:
-            six.raise_from(self._convert_exception(exc), exc)
+            raise self._convert_exception(exc) from exc
 
     def read_ap_multiple(self, addr, count=1, now=True):
         results = [self.read_ap(addr, True) for n in range(count)]
@@ -337,6 +345,7 @@ class PEMicroProbe(DebugProbe):
         else:
             return exc
 
+
 class PEMicroProbePlugin(Plugin):
     """! @brief Plugin class for PEMicroProbe."""
 
